@@ -15,12 +15,12 @@ use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
 
-package Sys::Async::Virt::Network v0.0.3;
+package Sys::Async::Virt::Network v0.0.4;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.3;
+use Protocol::Sys::Virt::Remote::XDR v0.0.4;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 use constant {
@@ -67,99 +67,99 @@ sub new {
 }
 
 sub create($self) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_NETWORK_CREATE,
-        { net => $self->{id},  } ));
+        { net => $self->{id} }, empty => 1 );
 }
 
 sub destroy($self) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_NETWORK_DESTROY,
-        { net => $self->{id},  } ));
+        { net => $self->{id} }, empty => 1 );
 }
 
 async sub get_autostart($self) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_GET_AUTOSTART,
-        { net => $self->{id},  } ))->{autostart};
+        { net => $self->{id} }, unwrap => 'autostart' );
 }
 
 async sub get_bridge_name($self) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_GET_BRIDGE_NAME,
-        { net => $self->{id},  } ))->{name};
+        { net => $self->{id} }, unwrap => 'name' );
 }
 
 async sub get_dhcp_leases($self, $mac, $flags = 0) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_GET_DHCP_LEASES,
-        { net => $self->{id}, mac => $mac, need_results => $remote->NETWORK_DHCP_LEASES_MAX, flags => $flags // 0 } ))->{leases};
+        { net => $self->{id}, mac => $mac, need_results => $remote->NETWORK_DHCP_LEASES_MAX, flags => $flags // 0 }, unwrap => 'leases' );
 }
 
 async sub get_metadata($self, $type, $uri, $flags = 0) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_GET_METADATA,
-        { network => $self->{id}, type => $type, uri => $uri, flags => $flags // 0 } ))->{metadata};
+        { network => $self->{id}, type => $type, uri => $uri, flags => $flags // 0 }, unwrap => 'metadata' );
 }
 
 async sub get_xml_desc($self, $flags = 0) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_GET_XML_DESC,
-        { net => $self->{id}, flags => $flags // 0 } ))->{xml};
+        { net => $self->{id}, flags => $flags // 0 }, unwrap => 'xml' );
 }
 
 async sub is_active($self) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_IS_ACTIVE,
-        { net => $self->{id},  } ))->{active};
+        { net => $self->{id} }, unwrap => 'active' );
 }
 
 async sub is_persistent($self) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_IS_PERSISTENT,
-        { net => $self->{id},  } ))->{persistent};
+        { net => $self->{id} }, unwrap => 'persistent' );
 }
 
 async sub list_all_ports($self, $flags = 0) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_LIST_ALL_PORTS,
-        { network => $self->{id}, need_results => $remote->NETWORK_PORT_LIST_MAX, flags => $flags // 0 } ))->{ports};
+        { network => $self->{id}, need_results => $remote->NETWORK_PORT_LIST_MAX, flags => $flags // 0 }, unwrap => 'ports' );
 }
 
 async sub port_create_xml($self, $xml, $flags = 0) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_PORT_CREATE_XML,
-        { network => $self->{id}, xml => $xml, flags => $flags // 0 } ))->{port};
+        { network => $self->{id}, xml => $xml, flags => $flags // 0 }, unwrap => 'port' );
 }
 
 async sub port_lookup_by_uuid($self, $uuid) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_NETWORK_PORT_LOOKUP_BY_UUID,
-        { network => $self->{id}, uuid => $uuid } ))->{port};
+        { network => $self->{id}, uuid => $uuid }, unwrap => 'port' );
 }
 
 sub set_autostart($self, $autostart) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_NETWORK_SET_AUTOSTART,
-        { net => $self->{id}, autostart => $autostart } ));
+        { net => $self->{id}, autostart => $autostart }, empty => 1 );
 }
 
 sub set_metadata($self, $type, $metadata, $key, $uri, $flags = 0) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_NETWORK_SET_METADATA,
-        { network => $self->{id}, type => $type, metadata => $metadata, key => $key, uri => $uri, flags => $flags // 0 } ));
+        { network => $self->{id}, type => $type, metadata => $metadata, key => $key, uri => $uri, flags => $flags // 0 }, empty => 1 );
 }
 
 sub undefine($self) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_NETWORK_UNDEFINE,
-        { net => $self->{id},  } ));
+        { net => $self->{id} }, empty => 1 );
 }
 
 sub update($self, $command, $section, $parentIndex, $xml, $flags = 0) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_NETWORK_UPDATE,
-        { net => $self->{id}, command => $command, section => $section, parentIndex => $parentIndex, xml => $xml, flags => $flags // 0 } ));
+        { net => $self->{id}, command => $command, section => $section, parentIndex => $parentIndex, xml => $xml, flags => $flags // 0 }, empty => 1 );
 }
 
 
@@ -176,7 +176,7 @@ Sys::Async::Virt::Network - Client side proxy to remote LibVirt network
 
 =head1 VERSION
 
-v0.0.3
+v0.0.4
 
 =head1 SYNOPSIS
 
