@@ -15,12 +15,12 @@ use warnings;
 use experimental 'signatures';
 use Future::AsyncAwait;
 
-package Sys::Async::Virt::StoragePool v0.0.3;
+package Sys::Async::Virt::StoragePool v0.0.4;
 
 use Carp qw(croak);
 use Log::Any qw($log);
 
-use Protocol::Sys::Virt::Remote::XDR v0.0.3;
+use Protocol::Sys::Virt::Remote::XDR v0.0.4;
 my $remote = 'Protocol::Sys::Virt::Remote::XDR';
 
 use constant {
@@ -55,111 +55,111 @@ sub new {
 }
 
 sub build($self, $flags = 0) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_BUILD,
-        { pool => $self->{id}, flags => $flags // 0 } ));
+        { pool => $self->{id}, flags => $flags // 0 }, empty => 1 );
 }
 
 sub create($self, $flags = 0) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_CREATE,
-        { pool => $self->{id}, flags => $flags // 0 } ));
+        { pool => $self->{id}, flags => $flags // 0 }, empty => 1 );
 }
 
 sub delete($self, $flags = 0) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_DELETE,
-        { pool => $self->{id}, flags => $flags // 0 } ));
+        { pool => $self->{id}, flags => $flags // 0 }, empty => 1 );
 }
 
 sub destroy($self) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_DESTROY,
-        { pool => $self->{id},  } ));
+        { pool => $self->{id} }, empty => 1 );
 }
 
 async sub get_autostart($self) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_GET_AUTOSTART,
-        { pool => $self->{id},  } ))->{autostart};
+        { pool => $self->{id} }, unwrap => 'autostart' );
 }
 
 sub get_info($self) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_GET_INFO,
-        { pool => $self->{id},  } ));
+        { pool => $self->{id} } );
 }
 
 async sub get_xml_desc($self, $flags = 0) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_GET_XML_DESC,
-        { pool => $self->{id}, flags => $flags // 0 } ))->{xml};
+        { pool => $self->{id}, flags => $flags // 0 }, unwrap => 'xml' );
 }
 
 async sub is_active($self) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_IS_ACTIVE,
-        { pool => $self->{id},  } ))->{active};
+        { pool => $self->{id} }, unwrap => 'active' );
 }
 
 async sub is_persistent($self) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_IS_PERSISTENT,
-        { pool => $self->{id},  } ))->{persistent};
+        { pool => $self->{id} }, unwrap => 'persistent' );
 }
 
 async sub list_all_volumes($self, $flags = 0) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_LIST_ALL_VOLUMES,
-        { pool => $self->{id}, need_results => $remote->STORAGE_VOL_LIST_MAX, flags => $flags // 0 } ))->{vols};
+        { pool => $self->{id}, need_results => $remote->STORAGE_VOL_LIST_MAX, flags => $flags // 0 }, unwrap => 'vols' );
 }
 
 async sub list_volumes($self) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_LIST_VOLUMES,
-        { pool => $self->{id}, maxnames => $remote->STORAGE_VOL_LIST_MAX } ))->{names};
+        { pool => $self->{id}, maxnames => $remote->STORAGE_VOL_LIST_MAX }, unwrap => 'names' );
 }
 
 async sub num_of_volumes($self) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_NUM_OF_VOLUMES,
-        { pool => $self->{id},  } ))->{num};
+        { pool => $self->{id} }, unwrap => 'num' );
 }
 
 sub refresh($self, $flags = 0) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_REFRESH,
-        { pool => $self->{id}, flags => $flags // 0 } ));
+        { pool => $self->{id}, flags => $flags // 0 }, empty => 1 );
 }
 
 sub set_autostart($self, $autostart) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_SET_AUTOSTART,
-        { pool => $self->{id}, autostart => $autostart } ));
+        { pool => $self->{id}, autostart => $autostart }, empty => 1 );
 }
 
 sub undefine($self) {
-    return ($self->{client}->_call(
+    return $self->{client}->_call(
         $remote->PROC_STORAGE_POOL_UNDEFINE,
-        { pool => $self->{id},  } ));
+        { pool => $self->{id} }, empty => 1 );
 }
 
 async sub vol_create_xml($self, $xml, $flags = 0) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_VOL_CREATE_XML,
-        { pool => $self->{id}, xml => $xml, flags => $flags // 0 } ))->{vol};
+        { pool => $self->{id}, xml => $xml, flags => $flags // 0 }, unwrap => 'vol' );
 }
 
 async sub vol_create_xml_from($self, $xml, $clonevol, $flags = 0) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_VOL_CREATE_XML_FROM,
-        { pool => $self->{id}, xml => $xml, clonevol => $clonevol, flags => $flags // 0 } ))->{vol};
+        { pool => $self->{id}, xml => $xml, clonevol => $clonevol, flags => $flags // 0 }, unwrap => 'vol' );
 }
 
 async sub vol_lookup_by_name($self, $name) {
-    return (await $self->{client}->_call(
+    return await $self->{client}->_call(
         $remote->PROC_STORAGE_VOL_LOOKUP_BY_NAME,
-        { pool => $self->{id}, name => $name } ))->{vol};
+        { pool => $self->{id}, name => $name }, unwrap => 'vol' );
 }
 
 
@@ -175,7 +175,7 @@ Sys::Async::Virt::StoragePool - Client side proxy to remote LibVirt storage pool
 
 =head1 VERSION
 
-v0.0.3
+v0.0.4
 
 =head1 SYNOPSIS
 
